@@ -8,7 +8,7 @@
 
 #include <time.h>
 
-#include <libsoup/soup-types.h>
+#include "soup-types.h"
 
 G_BEGIN_DECLS
 
@@ -19,24 +19,19 @@ G_BEGIN_DECLS
 #define SOUP_IS_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), SOUP_TYPE_CONNECTION))
 #define SOUP_CONNECTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), SOUP_TYPE_CONNECTION, SoupConnectionClass))
 
-struct SoupConnection {
+typedef struct {
 	GObject parent;
 
-};
+} SoupConnection;
 
 typedef struct {
 	GObjectClass parent_class;
 
 	/* signals */
-	void (*connect_result) (SoupConnection *, guint);
-	void (*disconnected)   (SoupConnection *);
+	void (*connect_result)  (SoupConnection *, guint);
+	void (*disconnected)    (SoupConnection *);
 
-	void (*authenticate)   (SoupConnection *, SoupMessage *,
-				const char *auth_type, const char *auth_realm,
-				char **username, char **password);
-	void (*reauthenticate) (SoupConnection *, SoupMessage *,
-				const char *auth_type, const char *auth_realm,
-				char **username, char **password);
+	void (*request_started) (SoupConnection *, SoupMessage *);
 
 	/* methods */
 	void (*send_request) (SoupConnection *, SoupMessage *);
@@ -45,25 +40,17 @@ typedef struct {
 GType soup_connection_get_type (void);
 
 
-/**
- * SoupConnectionCallback:
- * @conn: the #SoupConnection
- * @status: an HTTP status code indicating success or failure
- * @data: the data passed to soup_connection_connect_async()
- *
- * The callback function passed to soup_connection_connect_async().
- **/
 typedef void  (*SoupConnectionCallback)        (SoupConnection   *conn,
 						guint             status,
 						gpointer          data);
 
 
-#define SOUP_CONNECTION_ORIGIN_URI      "origin-uri"
-#define SOUP_CONNECTION_PROXY_URI       "proxy-uri"
+#define SOUP_CONNECTION_SERVER_ADDRESS  "server_address"
+#define SOUP_CONNECTION_PROXY_ADDRESS   "proxy-address"
 #define SOUP_CONNECTION_SSL_CREDENTIALS "ssl-creds"
-#define SOUP_CONNECTION_MESSAGE_FILTER  "message-filter"
 #define SOUP_CONNECTION_ASYNC_CONTEXT   "async-context"
-#define SOUP_CONNECTION_TIMEOUT		"timeout"
+#define SOUP_CONNECTION_TIMEOUT         "timeout"
+#define SOUP_CONNECTION_IDLE_TIMEOUT    "idle-timeout"
 
 SoupConnection *soup_connection_new            (const char       *propname1,
 						...) G_GNUC_NULL_TERMINATED;
@@ -75,6 +62,8 @@ guint           soup_connection_connect_sync   (SoupConnection   *conn);
 
 void            soup_connection_disconnect     (SoupConnection   *conn);
 
+SoupSocket     *soup_connection_get_socket     (SoupConnection   *conn);
+
 gboolean        soup_connection_is_in_use      (SoupConnection   *conn);
 time_t          soup_connection_last_used      (SoupConnection   *conn);
 
@@ -84,20 +73,6 @@ void            soup_connection_send_request   (SoupConnection   *conn,
 void            soup_connection_reserve        (SoupConnection   *conn);
 void            soup_connection_release        (SoupConnection   *conn);
 
-/* protected */
-void            soup_connection_authenticate   (SoupConnection   *conn,
-						SoupMessage      *msg,
-						const char       *auth_type,
-						const char       *auth_realm,
-						char            **username,
-						char            **password);
-void            soup_connection_reauthenticate (SoupConnection   *conn,
-						SoupMessage      *msg,
-						const char       *auth_type,
-						const char       *auth_realm,
-						char            **username,
-						char            **password);
-
 G_END_DECLS
 
 #endif /* SOUP_CONNECTION_H */
